=======
History
=======

0.2.0 (2016-11-8)
------------------

* Added projectdir.py script which finds directories for a given
  project id. Issue #3

* Added projectsearch.py script which given a string will search
  a postgres database for projects with that string in the name
  or description. 


0.1.1 (2016-10-14)
------------------

* Minor improvements to README.rst for better presentation on pypi

0.1.0 (2016-10-04)
------------------

* Initial release with single script mpidir.py
